@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# Application Name - Health Check V0.5.2-1
+# Application Name - Health Check V0.5.2-2
 # Date 17 February 2010
 # Author - Greg Roberts (Noobmonkey @ Maemo Talk)
 # Contact - Me@Greg-roberts.com
@@ -57,9 +57,6 @@ gtk.gdk.threads_init()
 import pygtk
 
 
-
-
-
 # Set a global variable - used to send the GPS info from a function back onto its label in the GUI. I'm sure there is a much better way returning
 # the variable in a function, but this works.... Example: http://www.wellho.net/resources/ex.php4?item=y105/locvar.py
 # Setting it to "location" for now.
@@ -167,11 +164,6 @@ class Ui_MainWindow(object):
         font = QtGui.QFont()
         font.setPointSize(12)
         # Set up the Front Camera label
-        #self.lbl_FrontCam = QtGui.QLabel(self.tab_3)
-        #self.lbl_FrontCam.setGeometry(QtCore.QRect(10, 130, 131, 21))
-        #self.lbl_FrontCam.setFont(font)
-        #self.lbl_FrontCam.setObjectName("lbl_FrontCam")
-        #self.lbl_FrontCam.setText("Camera Image")
 
         # This label is used to show the Front Camera widget
         self.lbl_CameraShow = QtGui.QLabel(self.tab_3)
@@ -221,6 +213,12 @@ class Ui_MainWindow(object):
         # Tell the button what to do when it is clicked. In this case i want it to run the updateTab1 function below
         QtCore.QObject.connect(self.pushButton_von, QtCore.SIGNAL('clicked()'), self.vibrateon)
 
+        self.pushButton_led = QtGui.QPushButton(self.tab_4)
+        self.pushButton_led.setGeometry(QtCore.QRect(10, 120, 391, 71))
+        self.pushButton_led.setObjectName("pushButton_led")
+        self.pushButton_led.setText("Test LED's")
+        # Tell the button what to do when it is clicked. In this case i want it to run the updateTab1 function below
+        QtCore.QObject.connect(self.pushButton_led, QtCore.SIGNAL('clicked()'), self.updateLED)
     
         self.tabWidget.addTab(self.tab_4, "")
 
@@ -233,7 +231,7 @@ class Ui_MainWindow(object):
         # box of some sort
         self.textBrowser = QtGui.QTextBrowser(self.tab_5)
         self.textBrowser.setGeometry(QtCore.QRect(0, 10, 781, 301))
-        self.textBrowser.setText (" Health Check V 0.5.2-1 \n Greg Roberts (Maemo.org - Noobmonkey) \n me@greg-roberts.com \n \n For Bugs and Feature requests: \n http://talk.maemo.org/showthread.php?p=541457")
+        self.textBrowser.setText (" Health Check V 0.5.2-2 \n Greg Roberts (Maemo.org - Noobmonkey) \n me@greg-roberts.com \n \n For Bugs and Feature requests: \n http://talk.maemo.org/showthread.php?p=541457")
         # Make the font small!!!
         font = QtGui.QFont()
         font.setPointSize(20)
@@ -248,18 +246,15 @@ class Ui_MainWindow(object):
         self.menubar.setObjectName("menubar")
         MainWindow.setMenuBar(self.menubar)
         # Draw the Status bar
-        #self.statusbar = QtGui.QStatusBar(MainWindow)
 
         # Run the translate UI - Added by QT Designer - i have removed alot of setText's and placed them above.
         self.retranslateUi(MainWindow)
         #self.updateTab1()
-        
-
+ 
         # Set which tab you want showing on program load
         self.tabWidget.setCurrentIndex(0)
         QtCore.QMetaObject.connectSlotsByName(MainWindow)
-        #Thread(target=self.updateTab1()).start()
-        
+  
 
     
         
@@ -271,35 +266,26 @@ class Ui_MainWindow(object):
         # Start of the GPS Location information
         # Please visit here for more information and code on PyMaemo GPS API - http://wiki.maemo.org/PyMaemo/Using_Location_API
 
-        #control = location.GPSDControl.get_default()
-        #device = location.GPSDevice()
-        
         loop = gobject.MainLoop()
         control = location.GPSDControl.get_default()
         device = location.GPSDevice()
         control.set_properties(preferred_method=location.METHOD_USER_SELECTED,preferred_interval=location.INTERVAL_DEFAULT)
-
         control.connect("error-verbose", on_error, loop)
         device.connect("changed", on_changed, control)
         control.connect("gpsd-stopped", on_stop, loop)
-
         gobject.idle_add(start_location, control)
 
         loop.run()
 
-    
-         # Set the GPS tabel text       
+        # Set the GPS tabel text       
         #self.lbl_Alt_Info.setText(var_g_ALT)
         self.listWidget2.addItem("GPS Position \t\t" + var_g_GPS.strip())
-
         al = '/sbin/ifconfig | grep inet | grep -v 127.0.0.1 | awk \'{split($2,a,":");print a[2]}\''
         l = None
         l = os.popen(al).read()
         self.listWidget2.addItem("Internal IP \t\t" + l.strip())
 
 
-        
-
     def reboot_sys(self):
         import gtk
         self.CloseDialog = QtGui.QMessageBox.question(None, "Time for a Reboot!","Do you really want to reboot?",QtGui.QMessageBox.Yes|QtGui.QMessageBox.No,QtGui.QMessageBox.No)
@@ -309,14 +295,17 @@ class Ui_MainWindow(object):
             b = os.popen('run-standalone.sh dbus-send --system --type=method_call --dest="com.nokia.dsme" --print-reply "/com/nokia/dsme/request" com.nokia.dsme.request.req_reboot')
             b.close ()
         elif self.CloseDialog == QtGui.QMessageBox.No:
-            print "User pressed 'Cancel' button"
+            print "User pressed 'No' button"
             
         
         
         
 # Funtion - update the front camera image
     def updateImage(self):
-       
+        bus = dbus.SessionBus()
+        proxy = bus.get_object('org.freedesktop.Notifications', '/org/freedesktop/Notifications')
+        interface = dbus.Interface(proxy,dbus_interface='org.freedesktop.Notifications')
+        interface.Notify('HealthCheck', 0, './healthcheck.png', 'Front Camera', 'Point your screen camera at a light.', [], {}, 3000)
         # Close b - the greatly named variable - as i want to use it again! (Well close or declare it!)
         b = None
         # X-term - grab 10 buffered front camera images, and throw them into an image file.
@@ -330,7 +319,11 @@ class Ui_MainWindow(object):
         self.lbl_CameraShow.setPixmap(image)
 
     def updateImage2(self):
-       
+        bus = dbus.SessionBus()
+        proxy = bus.get_object('org.freedesktop.Notifications', '/org/freedesktop/Notifications')
+        interface = dbus.Interface(proxy,dbus_interface='org.freedesktop.Notifications')
+        interface.Notify('HealthCheck', 0, './healthcheck.png', 'Back Camera', 'Open your Lens Cover!!.', [], {}, 3000)
+        
         # Close b - the greatly named variable - as i want to use it again! (Well close or declare it!)
         b = None
         # X-term - grab 10 buffered front camera images, and throw them into an image file.
@@ -398,7 +391,6 @@ class Ui_MainWindow(object):
         else:
            self.listWidget.addItem("Firmware Version \t\t" + g.strip() + " - Varient unknown")
 
-
 # Funtion - update CPU Information
     def updateCPU(self):
         # This one reads fremantle version number (Firmware)
@@ -415,7 +407,7 @@ class Ui_MainWindow(object):
         gc = os.popen('locale | grep LANG').read()
         gc = gc.strip()[5:]
         
-        self.listWidget.addItem("System locale \t\t" + gc.strip())
+        self.listWidget.addItem("System Locale \t\t" + gc.strip())
 
         gd = os.popen('cat /var/lib/dsme/boot_count').read()
         gd = gd.strip()        
@@ -423,11 +415,9 @@ class Ui_MainWindow(object):
 
         ge = os.popen('cat /sys/class/i2c-adapter/i2c-2/2-0063/power_level').read()
         ge = ge.strip()
-        
+    
         self.listWidget.addItem("FM Trans Strength \t\t" + ge.strip())
         
-        
-
     def updateUptime(self):
         # This one reads fremantle version number (Firmware)
         ge = os.popen('uptime|cut -d" " -f4-|cut -d"," -f-1').read()
@@ -442,9 +432,7 @@ class Ui_MainWindow(object):
         # Do some string functions to find/remove messy parts of the battery pulled text.
         # Please excuse the poorly labeled variables here!
         C_a = str(bg)[:-15]
-        
         C_b = str(C_a)[-4:]
-        
         barxval = str.strip(C_b)
         
         #self.lbl_Battery_Bar.setRange(0,100)
@@ -480,6 +468,10 @@ class Ui_MainWindow(object):
     def vibrateon(self):
         import dbus.glib
 
+        bus = dbus.SessionBus()
+        proxy = bus.get_object('org.freedesktop.Notifications', '/org/freedesktop/Notifications')
+        interface = dbus.Interface(proxy,dbus_interface='org.freedesktop.Notifications')
+        interface.Notify('HealthCheck', 0, './healthcheck.png', 'Vibration TEST', 'Testing Vibrations', [], {}, 3000)
         # set f to = the accellerometer co-ordinates
         # the co-ords need to be pulled out and split for easy reading
         # Close down the co-ord file once used (Only displaying static info, not updating yet)
@@ -515,7 +507,7 @@ class Ui_MainWindow(object):
         b.close()
         
         b.close()
-        bb= 'dbus-send --print-reply --system --dest=com.nokia.mce /com/nokia/mce/request com.nokia.mce.request.req_vibrator_pattern_deactivate string:' + "\'PatternIncomingCall\'"
+        bb= 'run-standalone.sh dbus-send --print-reply --system --dest=com.nokia.mce /com/nokia/mce/request com.nokia.mce.request.req_vibrator_pattern_deactivate string:' + "\'PatternIncomingCall\'"
         b = os.popen(bb)
         b.close()
         
@@ -528,6 +520,34 @@ class Ui_MainWindow(object):
         #for name, addr in nearby_devices:
             #print "  %s - %s" % (addr, name)
 
+    def updateLED(self):
+        import dbus.glib
+        bus = dbus.SessionBus()
+        proxy = bus.get_object('org.freedesktop.Notifications', '/org/freedesktop/Notifications')
+        interface = dbus.Interface(proxy,dbus_interface='org.freedesktop.Notifications')
+        interface.Notify('HealthCheck', 0, './healthcheck.png', 'LED TEST', 'Testing Power on, then SMS LED Patterns ', [], {}, 3000)
+
+        bb = 'run-standalone.sh dbus-send --system --type=method_call --dest=com.nokia.mce /com/nokia/mce/request com.nokia.mce.request.req_led_pattern_activate string:' + "\'PatternPowerOn\'"
+        b = os.popen(bb)
+        b.close()
+        bb = 'run-standalone.sh sleep 1'
+        b = os.popen(bb)
+        b.close()
+        bb = 'run-standalone.sh dbus-send --system --type=method_call --dest=com.nokia.mce /com/nokia/mce/request com.nokia.mce.request.req_led_pattern_deactivate string:' + "\'PatternPowerOn\'"
+        b = os.popen(bb)
+        b.close()
+
+        bb = 'run-standalone.sh dbus-send --system --type=method_call --dest=com.nokia.mce /com/nokia/mce/request com.nokia.mce.request.req_led_pattern_activate string:' + "\'PatternCommunicationSMS\'"
+        b = os.popen(bb)
+        b.close()
+        bb = 'run-standalone.sh sleep 1'
+        b = os.popen(bb)
+        b.close()
+        bb = 'run-standalone.sh dbus-send --system --type=method_call --dest=com.nokia.mce /com/nokia/mce/request com.nokia.mce.request.req_led_pattern_deactivate string:' + "\'PatternCommunicationSMS\'"
+        b = os.popen(bb)
+        b.close()
+
+      
 
 
 # Funtion - update rootfs, currently shows free MB and used %.
@@ -584,7 +604,7 @@ class Ui_MainWindow(object):
         bus = dbus.SessionBus()
         proxy = bus.get_object('org.freedesktop.Notifications', '/org/freedesktop/Notifications')
         interface = dbus.Interface(proxy,dbus_interface='org.freedesktop.Notifications')
-        interface.Notify('HealthCheck', 0, '/usr/share/icons/hicolor/scalable/hildon/healthcheck.png', 'System Tab', 'Finished Loading', [], {}, 2000)
+        interface.Notify('HealthCheck', 0, './healthcheck.png', 'System Tab', 'Finished Loading', [], {}, 2000)
 
 
 
@@ -596,6 +616,8 @@ class Ui_MainWindow(object):
         Thread(target=self.updateGPS()).start()
         self.pushButton_com.setText(".....")
         Thread(target=self.Cellular()).start()
+        self.pushButton_com.setText("......")
+        
         self.pushButton_com.setText("Update Tab")
         self.pushButton_com.setEnabled(True)
         self.pushButton_a2.setEnabled(True)
@@ -603,7 +625,7 @@ class Ui_MainWindow(object):
         bus = dbus.SessionBus()
         proxy = bus.get_object('org.freedesktop.Notifications', '/org/freedesktop/Notifications')
         interface = dbus.Interface(proxy,dbus_interface='org.freedesktop.Notifications')
-        interface.Notify('HealthCheck', 0, '/usr/share/icons/hicolor/scalable/hildon/healthcheck.png/healthcheck.png', 'Comms Tab', 'Finished Loading', [], {}, 2000)
+        interface.Notify('HealthCheck', 0, './healthcheck.png', 'Comms Tab', 'Finished Loading', [], {}, 2000)
 
     def updateTab3(self):
         self.pushButton_cam.setEnabled(False)
@@ -621,7 +643,7 @@ class Ui_MainWindow(object):
         
     # This is the start of the QT Designer translation function - not using the translation function, but left it in, to show it is part of the class   
     def retranslateUi(self, MainWindow):
-        MainWindow.setWindowTitle(QtGui.QApplication.translate("MainWindow", "Health Check 0.5.1-0", None, QtGui.QApplication.UnicodeUTF8))
+        MainWindow.setWindowTitle(QtGui.QApplication.translate("MainWindow", "Health Check 0.5.2-2", None, QtGui.QApplication.UnicodeUTF8))
         self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab), QtGui.QApplication.translate("MainWindow", "System", None, QtGui.QApplication.UnicodeUTF8))
         self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_2), QtGui.QApplication.translate("MainWindow", "Comms", None, QtGui.QApplication.UnicodeUTF8))
         self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_3), QtGui.QApplication.translate("MainWindow", "Camera", None, QtGui.QApplication.UnicodeUTF8))
